==> vaahai-0.2.16-py3-none-any.whl: vaahai/cli/commands/review/command.py <==
"""
VaahAI review command implementation.

This module contains the implementation of the review command,
which is used to perform code reviews on files or directories.
"""

import typer
from pathlib import Path
from typing import Optional
from rich.console import Console
from rich.panel import Panel

# Create a rich console for formatted output
console = Console()

# Create the review command group
review_app = typer.Typer(
    name="review",
    help="Perform code reviews on files or directories",
    add_completion=False,
)


@review_app.callback()
def callback():
    """
    Perform code reviews on files or directories.
    """
    pass


@review_app.command("run")
def run(
    path: Path = typer.Argument(
        ...,
        help="Path to the file or directory to review",
        exists=True,
    ),
    depth: str = typer.Option(
        "standard",
        "--depth",
        "-d",
        help="Depth of the review (quick, standard, thorough)",
    ),
    focus: Optional[str] = typer.Option(
        None,
        "--focus",
        "-f",
        help="Focus area for the review (quality, security, performance, etc.)",
    ),
):
    """
    Run a code review on the specified file or directory.
    """
    console.print(
        Panel.fit(
            f"[bold blue]Code Review[/bold blue]\n\n"
            f"Path: [green]{path}[/green]\n"
            f"Depth: [yellow]{depth}[/yellow]\n"
            f"Focus: [yellow]{focus or 'all'}[/yellow]\n\n"
            f"This is a placeholder for the code review functionality.\n"
            f"In the future, this will analyze the code and provide detailed feedback.",
            title="Code Review",
            border_style="blue",
        )
    )

==> vaahai-0.2.19-py3-none-any.whl: vaahai/cli/commands/review/command.py <==
"""
VaahAI review command implementation.

This module contains the implementation of the review command,
which is used to perform code reviews on files or directories.
"""

import typer
from pathlib import Path
from typing import Optional
from rich.console import Console
from rich.panel import Panel
from vaahai.cli.utils.help import create_typer_app, CustomHelpCommand

# Create a rich console for formatted output
console = Console()

# Create the review command group with custom help formatting
review_app = create_typer_app(
    name="review",
    help="Perform code reviews on files or directories",
    add_completion=False,
)


@review_app.callback()
def callback():
    """
    Perform code reviews on files or directories.
    """
    pass


@review_app.command("run", cls=CustomHelpCommand)
def run(
    path: Path = typer.Argument(
        ...,
        help="Path to the file or directory to review",
        exists=True,
    ),
    depth: str = typer.Option(
        "standard",
        "--depth",
        "-d",
        help="Depth of the review (quick, standard, thorough)",
    ),
    focus: Optional[str] = typer.Option(
        None,
        "--focus",
        "-f",
        help="Focus area for the review (quality, security, performance, etc.)",
    ),
):
    """
    Run a code review on the specified file or directory.
    
    This command analyzes the code in the specified path and provides
    feedback on code quality, potential bugs, and suggested improvements.
    """
    console.print(Panel(
        f"[bold]Reviewing:[/bold] {path}\n"
        f"[bold]Depth:[/bold] {depth}\n"
        f"[bold]Focus:[/bold] {focus or 'All areas'}",
        title="Code Review",
        border_style="blue",
    ))
    
    # Placeholder for actual review implementation
    console.print("[green]Review completed successfully![/green]")
